@@ -17,7 +17,7 @@ from .. import graphql_types
 from .. import conversion
 from .. import exceptions
 from ..operations import Operation
-from .django_errors import reraise_django_validation_error
+from .django_errors import reraise_from_django_validation_error
 from ._manager import ModelManager
 from ._fields import FieldsInfo, ForeignField, RelatedField
 
@@ -117,13 +117,14 @@ class DjangoModelManager(ModelManager):
                 graphql_path = graphql_path,
                 data = data,
             )
-        # validation
         try:
+            # validation
             instance.full_clean()
+            # save
+            instance.save()
         except django.core.exceptions.ValidationError as exception:
-            reraise_django_validation_error(graphql_path, exception)
-        # save
-        instance.save()
+            reraise_from_django_validation_error(
+                graphql_path, exception)
         # related data
         for field_name, children_data in related_data.items():
             for related_index, related_data in enumerate(children_data):
@@ -143,7 +144,8 @@ class DjangoModelManager(ModelManager):
             if callable(getattr(instance, 'clean_related', None)):
                 instance.clean_related()
         except django.core.exceptions.ValidationError as exception:
-            reraise_django_validation_error(graphql_path, exception)
+            reraise_from_django_validation_error(
+                graphql_path, exception)
         # post-save trigger
         self.model_config.on_after_operation(instance, authenticated_user, Operation.CREATE, data, depth)
         # result
@@ -255,13 +257,15 @@ class DjangoModelManager(ModelManager):
         # direct attributes
         for key, value in data.items():
             setattr(instance, key, value)
-        # validation (raise an easy_graphql_server exception instead of a Django one)
+        # validate & save (raise an easy_graphql_server exception instead of a Django one)
         try:
+            # validation
             instance.clean()
+            # save instance
+            instance.save()
         except django.core.exceptions.ValidationError as exception:
-            reraise_django_validation_error(graphql_path, exception)
-        # save instance
-        instance.save()
+            reraise_from_django_validation_error(
+                graphql_path, exception)
         # related data
         for field_name, children_data in related_data.items():
             related_field = self.fields_info.related[field_name]
@@ -305,7 +309,8 @@ class DjangoModelManager(ModelManager):
             if callable(getattr(instance, 'clean_related', None)):
                 instance.clean_related()
         except django.core.exceptions.ValidationError as exception:
-            reraise_django_validation_error(graphql_path, exception)
+            reraise_from_django_validation_error(
+                graphql_path, exception)
         # post-update trigger
         self.model_config.on_after_operation(instance, authenticated_user, Operation.UPDATE, data, depth)
         # result
@@ -353,14 +358,17 @@ class DjangoModelManager(ModelManager):
 
     # methods should be executed within an atomic database transaction
 
-    @staticmethod
-    def decorate(method):
+    def decorate(self, method, graphql_path=None):
         """
             Every exposed method will have to go through this decorator.
         """
         def decorated(*args, **kwargs):
             with django.db.transaction.atomic():
-                return method(*args, **kwargs)
+                try:
+                    return method(*args, **kwargs)
+                except django.core.exceptions.ValidationError as exception:
+                    reraise_from_django_validation_error(
+                        graphql_path or kwargs['graphql_path'], exception)
         return decorated
 
     # helpers for reading
